@@ -29,23 +29,23 @@ public class History implements Serializable {
 
 	boolean tryLock() {
 		if ( lock.isHeldByCurrentThread() )	return true;
-		Option.trace( "call tryLocak from %s", Thread.currentThread() );
+		Option.trace( "call tryLocak " );
 		boolean	ret = lock.tryLock();
-		Option.trace( "tryLocak %s from %s", ret, Thread.currentThread() );
+		Option.trace( "tryLocak %s ", ret  );
 		return ret;
 	}
 
 	void lock() {
 		if ( lock.isHeldByCurrentThread() )	return;
-		Option.trace( "call locak from %s", Thread.currentThread() );
+		Option.trace( "call locak " );
 		lock.lock();
-		Option.trace( "locaked from %s", Thread.currentThread() );
+		Option.trace( "locaked " );
 	}
 
 	void unlock() {
-		Option.trace( "call unlocak from %s", Thread.currentThread() );
+		Option.trace( "call unlocak " );
 		lock.unlock();
-		Option.trace( "unlocaked from %s", Thread.currentThread() );
+		Option.trace( "unlocaked " );
 	}
 
 	/**
