@@ -27,19 +27,26 @@ class OutputCall {
 
 	OutputCall( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
 		next_key = nk;
-		last_page = lp;
+		last_page = ( lp instanceof NullPage)?	null:	lp;
 		next_page = fw.getPage( lp );
 		forward = fw;
 		req = r;
 		data = sd;
+		next_page.setHistoryKey( next_key );
+	}
+
+	void call_main() throws Throwable {
+		next_page.setRequestParameter( req );
+		Option.trace( "%s/%s output(%s) call", next_page.getID(), next_page.getUniqueKey(), (last_page == null)?	"null": last_page.getID() );
+		Page	view = SandBox.output( next_page, last_page, req );
+		if ( view == null )	view = next_page;
+		next_page.setInitialized( false );
+		next_page.setRequestParameter( null );
+		out = new Page[]{ next_page, view };
 	}
 
 	void call() throws Throwable {
-		next_page.setHistoryKey( next_key );
 		PageID	last_id = null;
-		if ( last_page instanceof NullPage ) {
-			last_page = null;
-		}
 		if ( last_page != null ) {
 			last_id = last_page.getID();
 		}
@@ -57,13 +64,7 @@ class OutputCall {
 				}
 			}
 		}
-		next_page.setRequestParameter( req );
-		Option.trace( "%s/%s output(%s) call", next_page.getID(), next_page.getUniqueKey(), (last_page == null)?	"null": last_page.getID() );
-		Page	view = SandBox.output( next_page, last_page, req );
-		if ( view == null )	view = next_page;
-		next_page.setInitialized( false );
-		next_page.setRequestParameter( null );
-		out = new Page[]{ next_page, view };
+		call_main();
 	}
 
 	PostBack[] make() throws Exception {
@@ -87,7 +88,7 @@ class OpenOutput extends OutputCall {
 	void call() throws Throwable {
 		Popup	p = (Popup)forward;
 		if ( p.active_page != null )	return;
-		super.call();
+		call_main();
 	}
 
 	PostBack[] make() throws Exception {
@@ -142,6 +143,17 @@ class ScriptOutput extends OutputCall {
 	}
 }
 
+class NopOutput extends OutputCall {
+	NopOutput( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
+		super( nk, lp, fw, r, sd );
+	}
+	void call() throws Throwable {}
+	PostBack[] make() throws Exception {
+		Option.trace( "NOP JSON" );
+		return new PostBack[] { new PostBack() };
+	}
+}
+
 class LocationOutput extends OutputCall {
 	LocationOutput( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
 		super( nk, lp, fw, r, sd );
@@ -167,9 +179,9 @@ class OutputHolder {
 	private Forward[]		forward = null;
 	private OutputCall[]	opc = null;
 
-	OutputHolder( int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
-		Option.trace( "%s ajax %s", lp.getID(), lp.isAjax() );
-		AjaxForward[]	af = fw.getAjaxForward( lp.isAjax() );
+	OutputHolder( boolean ajax_f, int nk, Page lp, Forward fw, RequestParameter r, SessionData sd ) {
+		Option.trace( "%s ajax %s", lp.getID(), ajax_f );
+		AjaxForward[]	af = fw.getAjaxForward( ajax_f );
 		if ( af != null ) {
 			forward = new Forward[af.length];
 			for ( int i = 0; i < af.length; i++ ) {
@@ -181,41 +193,14 @@ class OutputHolder {
 			forward = new Forward[] { fw };
 			opc = new OutputCall[1];
 		}
-		if ( lp.isAjax() ) {
+		if ( ajax_f ) {
 			for ( int i = 0; i < forward.length; i++ ) {
-				if ( forward[i] instanceof JavaScript ){
-					Option.trace( "new ScriptOutput <- %s", forward[i] );
-					opc[i] = new ScriptOutput( nk, lp, forward[i], r, sd );
-				}
-				else if ( forward[i] instanceof Closure ) {
-					Closure	c = (Closure)forward[i];
-					if ( c.close_page.getPopupType() == null ) {
-						Option.trace( "new LocationOutput <- %s", forward[i] );
-						opc[i] = new LocationOutput( nk, lp, forward[i], r, sd );
-					}
-					else {
-						Option.trace( "new CloseOutput <- %s", forward[i] );
-						opc[i] = new CloseOutput( nk, lp, forward[i], r, sd );
-					}
-				}
-				else if ( forward[i] instanceof Feedback ) {
-					Option.trace( "new OutputCall <- %s", forward[i] );
-					opc[i] = new OutputCall( nk, lp, forward[i], r, sd );
-				}
-				else if ( forward[i] instanceof Popup ) {
-					Option.trace( "new OpenOutput <- %s", forward[i] );
-					Popup	p = (Popup)forward[i];
-					opc[i] = new OpenOutput( nk, lp, forward[i], p.getType(), r, sd );
-				}
-				else {
-					Option.trace( "new LocationOutput <- %s", forward[i] );
-					opc[i] = new LocationOutput( nk, lp, forward[i], r, sd );
-				}
+				opc[i] = forward[i].makeOutput( nk, lp, r, sd );
 			}
 			return;
 		}
-		Option.trace( "new OutputCall <- %s", fw );
-		opc[0] = new OutputCall( nk, lp, fw, r, sd );
+		Option.trace( "new OutputCall <- %s", forward[0] );
+		opc[0] = new OutputCall( nk, lp, forward[0], r, sd );
 	}
 
 	void call() throws Throwable {
