@@ -547,8 +547,7 @@ public class Tag extends HTMLPart {
 
 	/**
 	 * タグのインクルード。<br>
-	 * タグで挟まれた部分全てを取り込む。そのタグ自体は取り込まない。<br>
-	 * getReplica()したものを取り込みます。
+	 * include( tag, false ) と等価です。
 	 * @param tag 取り込むタグ。
 	 */
 	public void include( Tag tag ) {
@@ -559,15 +558,53 @@ public class Tag extends HTMLPart {
 		}
 	}
 
+	/**
+	 * タグのインクルード。<br>
+	 * タグで挟まれた部分全てを取り込む。そのタグ自体は取り込まない。<br>
+	 * move_f が true の時、引数のタグの内側のインスタンスが移動します。<br>
+	 * move_f が false の時、引数のタグの内側はそのままで、そのgetReplica()
+	 * したものを取り込みます。
+	 * @param tag 取り込むタグ。
+	 * @param move_f true:移動、false:コピー。
+	 */
+	public void include( Tag tag, boolean move_f ) {
+		if ( !move_f ) {
+			include( tag );
+			return;
+		}
+		if ( tag == null )	return;
+		int cnt = tag.getHTMLPartCount();
+		HTMLPart[]	data = new HTMLPart[cnt];
+		for ( int i = 0; i < cnt; i++ ) {
+			data[i] = tag.getHTMLPart( i );
+		}
+		tag.removeHTMLPart();
+		for ( int i = 0; i < cnt; i++ ) {
+			addHTMLPart( data[i] );
+		}
+	}
+
 	/**
 	 * HTMLのインクルード。<br>
-	 * bodyタグの内側部分全てを取り込む。
+	 * include( page, false ) と等価です。
 	 * @param page 取り込むページ。
 	 */
 	public void include( Page page ) {
-		Tag	tag = page.getFirstTagByType( "body" );
-		if ( tag == null )	return;
-		include( tag );
+		include( page, false );
+	}
+
+	/**
+	 * HTMLのインクルード。<br>
+	 * page の bodyタグの内側部分全てを取り込む。<br>
+	 * move_f が true の時、引数のタグの内側のインスタンスが移動します。<br>
+	 * move_f が false の時、引数のタグの内側はそのままで、そのgetReplica()
+	 * したものを取り込みます。
+	 * @param page 取り込むページ。
+	 * @param move_f true:移動、false:コピー。
+	 */
+	public void include( Page page, boolean move_f ) {
+		if ( page == null )	return;
+		include( page.getFirstTagByType( "body" ), move_f );
 	}
 
 	/**
