@@ -24,7 +24,7 @@ public class MultiTextBox extends Control {
 	}
 
 	protected Tag newReplica() {
-		return new MultiTextBox();
+		return copy4Replica( new MultiTextBox() );
 	}
 
 	/**
